@@ -12,12 +12,17 @@ from .. import utils
 def docker():
     pass
 
+
 @click.command(help="Configure and create infrastructure")
 @click.pass_obj
 @click.option("-I", "--non-interactive", is_flag=True, help="Run non-interactively")
 def login(context, non_interactive):
     user = context.user
-    cred = context.remote_config["ecrAdmin"] if user["role"] == "admin" else context.remote_config["ecrRead"]
+    cred = (
+        context.remote_config["ecrAdmin"]
+        if user["role"] == "admin"
+        else context.remote_config["ecrRead"]
+    )
     config = grvlms_config.load(context.root)
     if config["DOCKER_USE_AWS_ECR"]:
         click.echo(fmt.title("Generating command for docker login"))
@@ -29,11 +34,11 @@ def login(context, non_interactive):
             "get-login",
             "--no-include-email",
             "--region",
-            config["ECR_REGISTRY_REGION"]
+            config["ECR_REGISTRY_REGION"],
         )
         click.echo(fmt.title("Please copy and run command above"))
     else:
         utils.docker("login")
 
 
-docker.add_command(login) 
\ No newline at end of file
+docker.add_command(login)
