@@ -8,9 +8,7 @@ from openedx.core.djangoapps.plugins import constants as plugin_constants
 ALLOWED_HOSTS = [
     ENV_TOKENS.get("CMS_BASE"),
     "cms",
-    "127.0.0.1",
-    "localhost",
-    "studio.localhost",
+    "127.0.0.1"
 ]
 
 {{ patch("openedx-cms-production-settings") }}
