@@ -79,6 +79,7 @@ def reverse_host(domain):
     """
     return ".".join(domain.split(".")[::-1])
 
+
 def rsa_private_key(bits=2048):
     """
     Export an RSA private key in PEM format.
@@ -93,6 +94,7 @@ def rsa_import_key(key):
     """
     return RSA.import_key(key.encode())
 
+
 def long_to_base64(n):
     """
     Borrowed from jwkest.__init__
@@ -112,6 +114,7 @@ def long_to_base64(n):
     s = base64.urlsafe_b64encode(data).rstrip(b"=")
     return s.decode("ascii")
 
+
 def walk_files(path):
     """
     Iterate on file paths located in directory.
@@ -187,32 +190,42 @@ def check_output(*command):
         fmt.echo_error("Command failed: {}".format(" ".join(command)))
         raise
 
+
 def aws(id, key, profile, *command):
     if shutil.which("aws") is None:
         raise exceptions.GrvlmsError(
             "aws cli is not installed. Please follow instructions from https://docs.aws.amazon.com/cli/latest/userguide/cli-chap-install.html"
         )
-    
+
+    execute("aws", "configure", "set", "aws_access_key_id", id, "--profile", profile)
     execute(
-        "aws",
-        "configure",
-        "set",
-        "aws_access_key_id",
-        id,
-        "--profile",
-        profile
+        "aws", "configure", "set", "aws_secret_access_key", key, "--profile", profile
     )
+    return execute("aws", "--profile", profile, *command)
+
+
+def mkcert(config, mkcert_path):
+    wildcard_domain = config["WILDCARD_DOMAIN"]
+    if shutil.which("mkcert") is None:
+        raise exceptions.GrvlmsError(
+            "mkcert is not installed. Please follow instructions from https://github.com/FiloSottile/mkcert"
+        )
     execute(
-        "aws",
-        "configure",
-        "set",
-        "aws_secret_access_key",
-        key,
-        "--profile",
-        profile
+        "sudo",
+        "CAROOT={}".format(mkcert_path),
+        "mkcert",
+        "*.{}".format(wildcard_domain),
+    )
+    execute("sudo", "CAROOT={}".format(mkcert_path), "mkcert", "-install")
+    cert_file = "_wildcard.{}.pem".format(wildcard_domain.strip())
+    cert_key_file = "_wildcard.{}-key.pem".format(wildcard_domain.strip())
+    os.system(
+        "sudo chmod 0777 {cert_file} && sudo mv -f {cert_file} '{mkcert_path}/'".format(
+            cert_file=cert_file, mkcert_path=mkcert_path
+        )
+    )
+    os.system(
+        "sudo chmod 0777 {cert_key_file} && sudo mv -f {cert_key_file} '{mkcert_path}/'".format(
+            cert_key_file=cert_key_file, mkcert_path=mkcert_path
+        )
     )
-    return execute(
-        "aws",
-        "--profile", profile,
-         *command
-    )
\ No newline at end of file
